/////////////////////////////////////////////////////////////////////////////
// Name:        InterfaceImageBin.h
// Purpose:     InterfaceImageBin class
// Author:      Alain Bouju
// Modified by:
// Created:     02/02/00
// RCS-ID:      
// Copyright:   
// Licence:   
//////////////////////////////////////////////////////////////////////////////

/* Definition de la classe ImageBin */
#ifndef INTERFACEIMAGEBIN_H__
#define INTERFACEIMAGEBIN_H__

#include "define.h"
#include "Interface.h"

#ifdef __GNUG__
#pragma interface
#endif

#include "wx/wx.h"

#include "ImageBin.h"

class MyFrame;

class wxFrame;

class ImageBin;

class InterfaceImageBin{
public :
	wxMenu *g_wMenuImageBin;
	InterfaceImageBin ();
	~InterfaceImageBin (void);
	void InitInterfaceImageBin ( void );
	void OnImageBin(wxCommandEvent& event);
	void OnInverserBin();
	void OnDiviserBin();
	void OnErosionBin();
	void OnDilatationBin();
	void OnOuvertureBin();
	void OnFermetureBin();
	void OnNombreRegion();
	void OnSupprimerBin();
	wxBitmap * VisualiserBin (ImageBin *l_pImageBin);
	int AjouterImageBin(wxString l_wNomImage, ImageBin * l_pImageBin);
	ImageBin * ChercherImageBin(wxString l_wNomImage);
};

#endif
